# -*- coding: 'uft-8' -*-

"Módulo que contém todas as informações de busca do CEP"

# Third Part Imports
from bs4 import BeautifulSoup as BS
import requests


def crawling_cep(cep: str):
    """Função que buscará o cep no site dos correios

    Arguments:
        cep {str} -- [Número do cep. Pode conter - . ou apenas números]
    Return:
        Retorna um diconário com os dados do cep
    """
    url = "http://www.buscacep.correios.com.br/sistemas/buscacep/resultadoBuscaCepEndereco.cfm"
    lista = []

    # Apenas números
    if "." in cep or "-" in cep:
        cep = cep.replace('.', '').replace('-', '')

    # Iniciando requests
    r = requests.post(url, {"relaxation": cep})
    html = r.content

    # Formantando com beautiful soup
    soup = BS(html, 'lxml')
    for base in soup.find_all('td'):
        lista.append(base.text)

    # Guardando informações no dicionário
    try:
        informacoes = {
            "endereço": lista[0][: lista[0].find("\\")],
            "bairro": lista[1][: lista[1].find("\\")],
            "cidade": lista[2][: lista[2].find("/")],
            "uf": lista[2][lista[2].find("/")+1: lista[2].find("\\")]}
    except IndexError:
        return "CEP não encontrado"
    return informacoes


if __name__ == "__main__":
    print(crawling_cep("14098331"))
