# -*- coding: 'uft-8' -*-
"Módulo que contem as funções que farão a busca do CNPJ"

# Third Part Imports
from bs4 import BeautifulSoup as BS
import requests
import json


def crawling(cnpj):
    """Função que fará a busca dos cnpjs no site cnpj.biz

    :param cnpj: string
    :return: retorna uma lista com as informações da empresa
    """

    if "." in cnpj or "/" in cnpj or "-" in cnpj:
        cnpj = cnpj.replace('.', '').replace('-', '').replace('/', '')
    lista = []
    r = requests.get('https://cnpj.biz/{}'.format(str(cnpj)))
    html = r.content
    soup = BS(html, 'lxml')
    for base in soup.find_all('p'):
        lista.append(base.text)
    x = soup.find("div", "col c12")
    try:
        lista.append(x.text)
    except AttributeError:
        lista = [f"CNPJ {cnpj} não existente no banco de dados"]
    return lista


def formatando_dados(lista):
    """Função que organizará os dados adquiridos com a função crawuling()

    :param lista: receberá a lista contendo as informações da empresa
    """
    if "não existente" in lista[0]:
        empresa = lista
        return empresa

    empresa = {}
    
    for x in lista:
        if "Razão" in x:
            if "Recuperacao" in x:
                empresa["Situação especial"] = "Recuperação Judicial"
                empresa["Razão social"] = x[x.find(":")+1:len(x)]
                continue
            if "Falida" in x:
                empresa["Situação especial"] = "Falida"
                empresa["Razão social"] = x[x.find(":")+1:len(x)]
                continue
            else:
                empresa["Razão social"] = x[x.find(":")+1:len(x)]
                continue
        elif "Fantasia:" in x:
            empresa["Nome fantasia"] = x[x.find(":")+1:len(x)]
            continue
        elif "Situação:" in x:
            empresa["Situação"] = x[x.find(":")+1:len(x)]
            continue
        elif "Natureza Jurídica:" in x:
            empresa["Natureza"] = x[x.find(":")+1:len(x)]
            continue
        elif "Logradouro:" in x:
            empresa["Logradouro"] = x[x.find(":")+1:len(x)]
            continue
        elif "Complemento:" in x:
            empresa["Complemento"] = x[x.find(":")+1:len(x)]
            continue
        elif "Bairro:" in x:
            empresa["Bairro"] = x[x.find(":")+1:len(x)]
            continue
        elif "CEP:" in x:
            empresa["CEP"] = x[x.find(":")+1:len(x)]
            continue
        elif "Município:" in x:
            empresa["Municipio"] = x[x.find(":")+1:len(x)]
            continue
        elif "Estado:" in x:
            empresa["Estado"] = x[x.find(":")+1:len(x)]
            continue
        elif "Principal:" in x:
            empresa["Atividade Principal"] = x[x.find(":")+1:len(x)-1]
            continue
    return empresa



def crawling_cnpj(cnpj):
    """Função que fará a busca dos cnpjs no site receitaws

    :param cnpj: string
    :return: retorna uma lista com as informações da empresa
    """

    if "." in cnpj or "/" in cnpj or "-" in cnpj:
        cnpj = cnpj.replace('.', '').replace('-', '').replace('/', '')
    r = requests.get('http://receitaws.com.br/v1/cnpj/{}'.format(str(cnpj)))
    info = json.loads(r.text)
    return info


if __name__ == "__main__":
    x = crawling('19965360000156')
    print(formatando_dados(x))
