# -*- coding: 'uft-8' -*-
"""Módulo para realizar as consultas\n\n
from consultas.funcoes import buscando_cep\n
from consultas.funcoes import buscando_cnpj\n
from consultas.funcoes import buscando_cnpj_completo\n
from consultas.funcoes import buscando_cpf - em desenv.
"""
from consultas.cnpj.busca_cnpj import crawling, crawling_cnpj, formatando_dados
from consultas.cep.busca_cep import crawling_cep

# Third part imports
import sys


def buscando_cnpj_completo(cnpj: str):
    """Buscar informações completas de CNPJ. Não aceita lote
    Arguments:
        cnpj {str} -- [numero do cnpj: pode conter . / - ou apenas numeros]
        return {{dict}} -- [retorna o dicionário com as informações do CNPJ]
    """
    return crawling_cnpj(cnpj)


def buscando_cnpj(cnpj: str):
    """Buscar informações sobre um CNPJ
    Arguments:
        cnpj {[str]} -- [numero do cnpj: pode conter . / - ou apenas numeros]
        return {{dict}} -- [retorna o dicionário com as informações do CNPJ]
    """
    # try:
    #     return crawling_cnpj(cnpj)
    # except:
    return formatando_dados(crawling(cnpj))


def buscando_cpf(cpf: str):
    pass


def buscando_cep(cep: str):
    """Função que b usca o endereço nos site dos correios, partindo do CEP
    Arguments:
        cep {str} -- Número do cep
    Returns:
        [Dict] -- Retorna as informações do CEP
    """

    return crawling_cep(cep)


if __name__ == "__main__":
    if sys.argv[1].upper() == "CEP":
        print(buscando_cep(sys.argv[2]))
    elif sys.argv[1].upper() == "CNPJ":
        print(buscando_cnpj(sys.argv[2]))
    elif sys.argv[1].upper() == "CNPJ COMPLETO":
        print(buscando_cnpj_completo(sys.argv[2]))
    else:
        print("Especifique se a busca é para CEP, CNPJ ou CPF\nEx: python3 consultas.py \"CEP\" \"14098-331\"")
